@@ -6,6 +6,7 @@ class ChannelType(Enum):
     AMAZON = "amazon"
     GOOGLE = "google"
     TWILIO = "twilio"
+    AMAZON_NEURAL = "amazon_neural"
 
 
 CHANNEL_STORAGE_FOLDER = {
@@ -13,8 +14,10 @@ CHANNEL_STORAGE_FOLDER = {
     ChannelType.AMAZON.value: "alexa",
     ChannelType.GOOGLE.value: "google",
     ChannelType.TWILIO.value: "alexa",
+    ChannelType.AMAZON_NEURAL.value: "amazon_neural",
 }
 
+
 CCML_DICTIONARY = {
     ChannelType.AWS_POLLY.value: {
         "speak": None,
@@ -24,6 +27,9 @@ CCML_DICTIONARY = {
         "emotion": "amazon:emotion",
         "language": "lang",
         "part-of-speech": "w",
+        "say-as": None,
+        "prosody": None,
+        "emphasis": None,
     },
     ChannelType.AMAZON.value: {
         "phoneme": None,
@@ -35,6 +41,9 @@ CCML_DICTIONARY = {
         "emotion": "amazon:emotion",
         "speak": None,
         "audio": None,
+        "say-as": None,
+        "prosody": None,
+        "emphasis": None,
     },
     ChannelType.GOOGLE.value: {
         "mark": None,
@@ -43,19 +52,29 @@ CCML_DICTIONARY = {
         "sequential": "seq",
         "speak": None,
         "audio": None,
+        "say-as": None,
+        "prosody": None,
+        "emphasis": None,
     },
     ChannelType.TWILIO.value: {
         "part-of-speech": "w",
         "language": "lang",
         "phoneme": None,
+        "say-as": None,
+        "prosody": None,
+        "emphasis": None,
+    },
+    ChannelType.AMAZON_NEURAL.value: {
+        "speak": None,
+        "phoneme": None,
+        "domain": "amazon:domain",
+        "language": "lang",
+        "part-of-speech": "w",
     },
     "common": {
         "break": None,
-        "say-as": None,
         "p": None,
         "s": None,
-        "prosody": None,
-        "emphasis": None,
         "sub": None,
     },
 }
